@@ -4,7 +4,7 @@ import io
 import geopandas as gpd
 import numpy as np
 from pygeoogc import ArcGISRESTful, ServiceURL
-from shapely.geometry import LineString, MultiPolygon, Point, Polygon, box
+from shapely import LineString, MultiPolygon, Point, Polygon, box
 
 import pygeoutils as geoutils
 from pygeoutils import Coordinates, GeoBSpline
@@ -76,7 +76,7 @@ def test_bspline():
             (-97.06127, 32.832),
         ]
     )
-    pts = gpd.GeoSeries(gpd.points_from_xy(xl, yl, crs="epsg:4326")).to_crs("epsg:3857")
+    pts = gpd.GeoSeries(gpd.points_from_xy(xl, yl, crs=4326)).to_crs("epsg:3857")
     sp = GeoBSpline(pts, 10).spline
     assert len(sp.x) == 10
     assert_close(sum(sp.y), 38734230.680)
@@ -359,6 +359,47 @@ def test_nested():
     assert geoutils.nested_polygons(gdf) == {2: [1], 0: [4]}
 
 
+def test_coords():
+    coords = (1, 2)
+    clist = geoutils.coords_list(coords)
+    assert isinstance(clist, list) and all(len(c) == 2 for c in clist)
+
+    coords = ((1, 2), (1, 2, 4))
+    clist = geoutils.coords_list(coords)
+    assert isinstance(clist, list) and all(len(c) == 2 for c in clist)
+
+    coords = np.array(((1, 2), (1, 3)))
+    clist = geoutils.coords_list(coords)
+    assert isinstance(clist, list) and all(len(c) == 2 for c in clist)
+
+
+def test_mp2p():
+    gdf = gpd.GeoDataFrame(
+        geometry=[MultiPolygon([box(6, 6, 8, 8), box(6, 6, 6.01, 6.01)]), box(2, 2, 5, 5)],
+        crs=5070,
+    )
+    gdf = geoutils.multi2poly(gdf)
+    assert (gdf.geometry.geom_type == "Polygon").all() and gdf.shape[0] == 2
+
+    gdf = gpd.GeoDataFrame(
+        geometry=[MultiPolygon([box(3, 3, 5, 5), box(6, 6, 8, 8)]), box(2, 2, 5, 5)],
+        crs=5070,
+    )
+    gdf = geoutils.multi2poly(gdf)
+    assert (gdf.geometry.geom_type == "MultiPolygon").sum() == 1
+
+    gdf = gpd.GeoDataFrame(
+        geometry=[
+            MultiPolygon([box(3, 3, 5, 5), box(6, 6, 8, 8)]),
+            box(8, 8, 9, 9),
+            MultiPolygon([box(2, 2, 5, 5)]),
+        ],
+        crs=5070,
+    )
+    gdf = geoutils.multi2poly(gdf)
+    assert (gdf.geometry.geom_type == "Polygon").sum() == 2
+
+
 def test_show_versions():
     f = io.StringIO()
     geoutils.show_versions(file=f)
